pypoker
========

`pypoker` is a cliff based app for evaluating poker hands.

Installation
-------------

To install `pypoker`:

	$ pip install pypoker==0.0.2a

Usage
------

Once installed, use `pypoker` by running the following in a terminal.

       $ pypoker evaluate -e As Ks Qs Js 10s

Or enter the pypoker interactive shell by simply typing "pypoker" at the command line once installed.